@@ -5,19 +5,19 @@
 #' @description
 #' Data exploration and modelling is a process in which a lot of data artifacts are produced. 
 #' Artifacts like: subsets, data aggregates, plots, statistical models, different  versions of data sets and different versions of results. 
-#' The more projects we work with the more artifacts are produced and the harder it is to manage these artifacts. 
+#' The more projects we work on, the more artifacts are produced and the harder it is to manage these artifacts. 
 #' 
 #' Archivist helps to store and manage artifacts created in R.
 #' 
 #' Archivist allows you to store selected artifacts as binary files
-#'   together with their metadata and relations.
+#' along with their metadata and relations.
 #' Archivist allows you to share artifacts with others, either through a shared folder or github.
-#' Archivist allows you to look for already created artifacts by using its class, 
-#'  name, date of creation or other properties.
+#' Archivist allows you to look for artifacts by using its class, 
+#' name, date of creation or other properties.
 #' It also facilitates restoring such artifacts.
-#' Archivist allows to check if a new artifact is the exact 
-#'  copy of the one that was produced some time ago.
-#'  This might be useful either for testing or caching.
+#' Archivist allows you to check if a new artifact is the exact 
+#' copy of the one that was produced some time ago.
+#' This might be useful either for testing or caching.
 #'
 #' The list of main use cases is available here \href{https://github.com/pbiecek/archivist}{https://github.com/pbiecek/archivist}.
 #'
@@ -31,6 +31,7 @@
 #' Marcin Kosinski [aut] \email{m.p.kosinski@@gmail.com}
 #' 
 #' @importFrom RCurl getBinaryURL
+#' @importFrom RCurl url.exists
 #' @import httr
 #' @importFrom DBI dbWriteTable
 #' @importFrom DBI dbGetQuery
@@ -43,7 +44,41 @@
 #' @importFrom RSQLite SQLite
 #' @importFrom lubridate now
 #' @importFrom digest digest
+#' @importFrom grDevices dev.off
+#' @importFrom grDevices png
+#' @importFrom graphics barplot
+#' @importFrom graphics par
+#' @importFrom graphics plot
+#' @importFrom utils head
+#' @importFrom utils zip
+#' @importFrom knitr kable
+#' @importFrom utils tail
+#' @importMethodsFrom git2r add
+#' @importMethodsFrom git2r commit
+#' @importMethodsFrom git2r push
+#' @importMethodsFrom git2r init
+#' @importMethodsFrom git2r remote_add
+#' @importMethodsFrom git2r clone
+#' @importMethodsFrom git2r repository
+#' @importMethodsFrom git2r discover_repository
+#' @importMethodsFrom git2r in_repository
+#' @importMethodsFrom git2r cred_user_pass
+#' @importClassesFrom git2r cred_user_pass
+#' @importClassesFrom git2r git_repository
+#' @importFrom jsonlite unbox
+#'
 #' @family archivist
 #' @name archivist-package
 #' @docType package
 invisible(NULL)
+#' Pipe operator
+#'
+#' See \code{\link[magrittr]{\%>\%}} for more details.
+#'
+#' @name %>%
+#' @rdname pipe
+#' @keywords internal
+#' @export
+#' @importFrom magrittr %>%
+#' @usage lhs \%>\% rhs
+NULL
\ No newline at end of file
