@@ -10,12 +10,12 @@
 #' @details
 #' Functions \code{loadFromLocalRepo} and \code{loadFromGithubRepo} load artifacts from the archivist Repositories 
 #' stored in a local folder or on Github. Both of them take \code{md5hash} as a
-#' parameter, which is a result from \link{saveToRepo} function.
-#' For every artifact, \code{md5hash} is a unique string of length 32 that comes out as a result of 
+#' parameter, which is a result of \link{saveToRepo} function.
+#' For each artifact, \code{md5hash} is a unique string of length 32 that is produced by
 #' \link[digest]{digest} function, which uses a cryptographical MD5 hash algorithm. For more information see \link{md5hash}.
 #' 
 #' Important: instead of giving the whole \code{md5hash} character, the user can simply give first few characters of the \code{md5hash}.
-#' For example, \code{a09dd} instead of \code{a09ddjdkf9kj33dcjdnfjgos9jd9jkcv}. All artifacts with the same corresponing \code{md5hash} 
+#' For example, \code{a09dd} instead of \code{a09ddjdkf9kj33dcjdnfjgos9jd9jkcv}. All artifacts with the same \code{md5hash} 
 #' abbreviation will be loaded from \link{Repository}.
 #' 
 #' Note that \code{user} and \code{repo} should be used only when working with a Github repository and should be omitted in the local mode. 
@@ -23,8 +23,8 @@
 #' 
 #' One may notice that \code{loadFromGithubRepo} and \code{loadFromLocalRepo} load artifacts to the Global
 #' Environment with their original names. Alternatively,
-#' a parameter \code{value = TRUE} might be specified so that the functions return artifacts as a result so that they
-#' can be attributed to new names. Note that, when an abbreviation of \code{md5hash} was given a list of artifacts corresponding to this
+#' a parameter \code{value = TRUE} can be specified so that these functions may return artifacts as a value. As a result loaded artifacts
+#' can be attributed to new names. Note that, when an abbreviation of \code{md5hash} was given then a list of artifacts corresponding to this
 #' abbreviation will be loaded.
 #' 
 #' @note
@@ -34,18 +34,18 @@
 #' set in \link{setGithubRepo} function are used.
 #' 
 #' @param repoDir A character denoting an existing directory from which an artifact will be loaded.
-#' If set to \code{NULL} (by default), uses the \code{repoDir} specified in \link{setLocalRepo}.
+#' If it is set to \code{NULL} (by default), it will use the \code{repoDir} specified in \link{setLocalRepo}.
 #' 
-#' @param md5hash A character assigned to the artifact as a result of a cryptographical hash function with MD5 algorithm, or it's abbreviation.
+#' @param md5hash A character assigned to the artifact through the use of a cryptographical hash function with MD5 algorithm, or it's abbreviation.
 #' 
-#' @param repo Only if working with a Github repository. A character containing a name of a Github repository on which the Repository is archived.
+#' @param repo While working with a Github repository. A character containing a name of a Github repository on which the Repository is archived.
 #' By default set to \code{NULL} - see \code{Note}.
-#' @param user Only if working with a Github repository. A character containing a name of a Github user on whose account the \code{repo} is created.
+#' @param user While working with a Github repository. A character containing a name of a Github user on whose account the \code{repo} is created.
 #' By default set to \code{NULL} - see \code{Note}. 
-#' @param branch Only if working with a Github repository. A character containing a name of 
+#' @param branch While working with a Github repository. A character containing a name of 
 #' Github Repository's branch on which the Repository is archived. Default \code{branch} is \code{master}.
 #' 
-#' @param repoDirGit Only if working with a Github repository. A character containing a name of a directory on Github repository 
+#' @param repoDirGit While working with a Github repository. A character containing a name of a directory on Github repository 
 #' on which the Repository is stored. If the Repository is stored in main folder on Github repository, this should be set 
 #' to \code{repoDirGit = FALSE} as default.
 #' 
@@ -53,14 +53,14 @@
 #' if \code{TRUE} then artifacts are returned as a list of values (if there is more than one artifact)
 #' or as a single value (if there is only one arfifact that matches md5hash).
 #' 
-#' 
-#'
 #' @author 
 #' Marcin Kosinski , \email{m.p.kosinski@@gmail.com}
-#' 
+#'  
 #' @examples
-#' # objects preparation
+#' 
 #' \dontrun{
+#' # objects preparation
+#' 
 #' # data.frame object
 #' data(iris)
 #' 
@@ -89,9 +89,9 @@
 #'            cbind(rnorm( 3,3.2,0.5), rnorm( 3,3.2,0.5)))
 #' fannyx <- fanny(x, 2)
 #' 
-#' # creating example Repository - that examples will work
+#' # creating example Repository - on which examples will work
 #' 
-#' exampleRepoDir <- tempdir()
+#' exampleRepoDir <- tempfile()
 #' createEmptyRepo(repoDir = exampleRepoDir)
 #' myplo123Md5hash <- saveToRepo(myplot123, repoDir=exampleRepoDir)
 #' irisMd5hash <- saveToRepo(iris, repoDir=exampleRepoDir)
@@ -99,12 +99,12 @@
 #' agn1Md5hash <- saveToRepo(agn1, repoDir=exampleRepoDir)
 #' fannyxMd5hash <- saveToRepo(fannyx, repoDir=exampleRepoDir)
 #' 
-#' # let's see how the Repository look like: show
+#' # let's see how the Repository looks like: show
 #' 
 #' showLocalRepo(method = "md5hashes", repoDir = exampleRepoDir)
 #' showLocalRepo(method = "tags", repoDir = exampleRepoDir)
 #' 
-#' # let's see how the Repository look like: summary
+#' # let's see how the Repository looks like: summary
 #' 
 #' summaryLocalRepo( exampleRepoDir )
 #' 
@@ -116,14 +116,14 @@
 #' rm(agn1)
 #' 
 #' # if those objects were archivised, they can be loaded
-#' # from Repository, when knowing their tags
+#' # from Repository, when knowing their md5hash
 #' 
 #' loadFromLocalRepo(myplo123Md5hash, repoDir = exampleRepoDir)
 #' loadFromLocalRepo(irisMd5hash, repoDir = exampleRepoDir)
 #' 
 #' 
-#' # if one can not remembers the object's md5hash but
-#' # remembers the object's name this object can still be
+#' # if one doesn't remember the object's md5hash but
+#' # remembers the object's name, this object can still be
 #' # loaded.
 #' 
 #' agnesHash <- searchInLocalRepo( "name:agn1", repoDir = exampleRepoDir)
@@ -146,6 +146,9 @@
 #' # and can be loaded as a value from it's abbreviation
 #' newModel  <- loadFromLocalRepo("cd6557c", repoDir = exampleRepoDir, value = TRUE)
 #' # note that "model" was not deleted
+
+#' # removing an example Repository
+#' deleteRepo( exampleRepoDir, TRUE)
 #' 
 #' #
 #' #GitHub Version
@@ -169,9 +172,42 @@
 #' 
 #' loadFromGithubRepo( "ff575c261c", user="pbiecek", repo="archivist")
 #' NewObjects <- loadFromGithubRepo( NAMEmd5hash, user="pbiecek", repo="archivist", value = TRUE )
-#' loadFromGithubRepo( DATEmd5hash, user="pbiecek", repo="archivist")
+#' loadFromGithubRepo( CLASSmd5hash, user="pbiecek", repo="archivist")
 #' 
 #' 
+#' ## Loading artifacts from the repository which is built in the archivist package 
+#' ## and saving them on the example repository
+#' 
+#' # Creating an example Repository - on which artifacts loaded from the
+#' # archivist package repository will be saved
+#' exampleRepoDir <- tempfile()
+#' createEmptyRepo(repoDir = exampleRepoDir)
+#' 
+#' # Directory of the archivist package repository
+#' repo_archivist <- system.file("graphGallery", package = "archivist") 
+#' 
+#' # We are checking what kind of objects
+#' # are stored in the archivist package repository
+#' summaryLocalRepo(repoDir = repo_archivist)
+#' 
+#' # Let's say that we are interested in 
+#' # an artifact of class ggplot.
+#' GGPLOTmd5hash <- searchInLocalRepo(pattern = "class:ggplot",
+#'                                    repoDir = repo_archivist) 
+#' # There are eight of them.
+#' # We load the first one by its value (parameter value = TRUE)
+#' # and assign it to the p variable.
+#' p <- loadFromLocalRepo(GGPLOTmd5hash[1], repoDir = repo_archivist,
+#'                        value = TRUE)
+#' 
+#' # Finally, we may save the artifact on the example Repository.
+#' # Note that md5hash is different from the one which is stored in
+#' # the archivist package repository.
+#' saveToRepo(p, repoDir = exampleRepoDir) 
+#' 
+#' # Making sure that the artifact is stored on the example repository
+#' showLocalRepo(repoDir = exampleRepoDir, method = "tags")
+#' 
 #' # removing an example Repository
 #' 
 #' deleteRepo( exampleRepoDir, TRUE)
@@ -192,8 +228,8 @@
 #' @rdname loadFromRepo
 #' @export
 loadFromLocalRepo <- function( md5hash, repoDir = NULL, value = FALSE ){
-  stopifnot( is.character( md5hash ) )
-  stopifnot( is.character( repoDir ) | is.null( repoDir ) )
+  stopifnot( is.character( md5hash ), length( md5hash ) == 1 )
+  stopifnot( (is.character( repoDir ) & length( repoDir ) == 1) | is.null( repoDir ) )
   stopifnot( is.logical( value ) )
   
   repoDir <- checkDirectory( repoDir )
@@ -209,13 +245,13 @@ loadFromLocalRepo <- function( md5hash, repoDir = NULL, value = FALSE ){
   # using sapply in case abbreviation mode found more than 1 md5hash
   if ( !value ) {
     sapply( md5hash, function(x) {
-      load( file = paste0( repoDir, "gallery/", x, ".rda" ), envir = .GlobalEnv )
+      load( file = file.path( repoDir, "gallery", paste0(x, ".rda" )), envir = .GlobalEnv )
     } )
   }else{
     .nameEnv <- new.env()
     name <- character( length = length( md5hash ) )
     for( i in seq_along( md5hash ) ) {
-      name[i] <- load( file = paste0( repoDir, "gallery/", md5hash[i], ".rda" ), 
+      name[i] <- load( file = file.path( repoDir, "gallery", paste0(md5hash[i], ".rda") ), 
                        envir = .nameEnv ) 
       }
     if ( length( name ) == 1) {
@@ -229,7 +265,7 @@ loadFromLocalRepo <- function( md5hash, repoDir = NULL, value = FALSE ){
 #' @rdname loadFromRepo
 #' @export
 loadFromGithubRepo <- function( md5hash, repo = NULL, user = NULL, branch = "master", repoDirGit = FALSE, value = FALSE ){
-  stopifnot( is.character( c( md5hash, branch ) ) )
+  stopifnot( is.character( c( md5hash, branch ) ), length( md5hash ) == 1, length( branch ) == 1 )
   stopifnot( is.logical( value ) )
   
   GithubCheck( repo, user, repoDirGit ) # implemented in setRepo.R
@@ -239,7 +275,7 @@ loadFromGithubRepo <- function( md5hash, repo = NULL, user = NULL, branch = "mas
   if ( nchar( md5hash ) < 32 ){
     # database is needed to be downloaded
     Temp <- downloadDB( repo, user, branch, repoDirGit )
-    
+      
     md5hashList <- executeSingleQuery( dir = Temp, realDBname = FALSE,
                                        paste0( "SELECT DISTINCT artifact FROM tag WHERE artifact LIKE '",md5hash,"%'" ) )
     md5hash <- as.character( md5hashList[, 1] )
@@ -253,13 +289,13 @@ loadFromGithubRepo <- function( md5hash, repo = NULL, user = NULL, branch = "mas
     # sapply and replicate because of abbreviation mode can find more than 1 md5hash
     if( is.character( repoDirGit )){
     tmpobjectS <- lapply( md5hash, function(x){
-      getBinaryURL( paste0( get( x = ".GithubURL", envir = .ArchivistEnv), user, "/", repo, "/",
-                            branch, "/", repoDirGit, "/gallery/", x, ".rda") )  } )
+      getBinaryURL( file.path( get( x = ".GithubURL", envir = .ArchivistEnv), user, repo,
+                            branch, repoDirGit, "gallery", paste0(x, ".rda") ) )  } )
     }
     if( is.logical( repoDirGit )){
       tmpobjectS <- lapply( md5hash, function(x){
-        getBinaryURL( paste0( get( x = ".GithubURL", envir = .ArchivistEnv), user, "/", repo, "/",
-                              branch, "/gallery/", x, ".rda") )  } )  
+        getBinaryURL( file.path( get( x = ".GithubURL", envir = .ArchivistEnv), user, repo,
+                              branch, "gallery", paste0(x, ".rda") ) )  } )  
     }
     tfS <- replicate( length( md5hash ), tempfile() )
         
@@ -275,13 +311,13 @@ loadFromGithubRepo <- function( md5hash, repo = NULL, user = NULL, branch = "mas
     # sapply and replicate because of abbreviation mode can find more than 1 md5hash
     if( is.character( repoDirGit )){
       tmpobjectS <- lapply( md5hash, function(x){
-        getBinaryURL( paste0( get( x = ".GithubURL", envir = .ArchivistEnv), user, "/", repo, "/",
-                              branch, "/", repoDirGit, "/gallery/", x, ".rda") )  } )
+        getBinaryURL( file.path( get( x = ".GithubURL", envir = .ArchivistEnv), user, repo,
+                              branch, repoDirGit, "gallery", paste0(x, ".rda") ) )  } )
     }
     if( is.logical( repoDirGit )){
       tmpobjectS <- lapply( md5hash, function(x){
-        getBinaryURL( paste0( get( x = ".GithubURL", envir = .ArchivistEnv), user, "/", repo, "/",
-                              branch, "/gallery/", x, ".rda") )  } )  
+        getBinaryURL( file.path( get( x = ".GithubURL", envir = .ArchivistEnv), user, repo,
+                              branch, "gallery", paste0(x, ".rda") ) )  } )  
     }
     tfS <- replicate( length( md5hash ), tempfile() )
     
