@@ -11,9 +11,9 @@
 #' Artifacts are saved in the local Repository, which is a SQLite database named \code{backpack}. 
 #' After every \code{saveToRepo} call the database is refreshed, so the artifact is available 
 #' immediately in the database for other collaborators.
-#' Every artifact is archived in a \code{md5hash.rda} file. This file will be saved in a folder 
-#' (under \code{repoDir} directory) named \code{gallery}. For every artifact, \code{md5hash} is a 
-#' unique string of length 32 that comes out as a result of 
+#' Each artifact is archived in a \code{md5hash.rda} file. This file will be saved in a folder 
+#' (under \code{repoDir} directory) named \code{gallery}. For each artifact, \code{md5hash} is a 
+#' unique string of length 32 that is produced by 
 #' \link[digest]{digest} function, which uses a cryptographical MD5 hash algorithm.
 #' 
 #' By default, a miniature of an artifact and (if possible) a data set needed to compute this artifact are extracted. 
@@ -31,13 +31,18 @@
 #' \link{searchInLocalRepo} or \link{searchInGithubRepo} functions. Artifacts can be searched by their \link{Tags}, 
 #' \code{names}, \code{classes} or \code{archiving date}.
 #' 
-#' Graphical parameters.
+#' \code{firstRows} parameter.
 #' 
-#' If the artifact is of class \code{data.frame} or \code{archiveData = TRUE}, it is possible to specify 
-#' how many rows of that data should be archived by adding the argument \code{firstRows} with the n
-#' specified number of rows. Note that, the date can be extracted only from the artifacts that are supported by 
+#' If the artifact is of class \code{data.frame} or user set \code{archiveData = TRUE} for artifact that stores data within it,
+#'  it is possible to specify 
+#' how many rows of that data (or that \code{data.frame}) should be archived in a \code{miniature}.
+#'  This can be done by adding the argument \code{firstRows} with the
+#' n corresponding to the number of rows (as in \link{head}).
+#' Note that, the data can be extracted only from the artifacts that are supported by 
 #' the \pkg{archivist} package; see \link{Tags}.
 #' 
+#' Graphical parameters.
+#' 
 #' If the artifact is of class \code{lattice} or \code{ggplot}, and
 #' \code{archiveMiniature = TRUE}, then it is 
 #' possible to set the miniature's \code{width} and \code{height} parameters. By default they are set to
@@ -58,13 +63,13 @@
 #'  \item \code{survfit}.
 #'  }
 #'  
-#' To check what \code{Tags} will be extracted for various artifacts see \link{Tags}.
+#' To check what \code{Tags} will be extracted from various artifacts see \link{Tags}.
 #' 
 #' @return
-#' As a result of this function a character string is returned, which determines
-#' the \code{md5hash} of the artifact that was used in the \code{saveToRepo} function. If  
-#' \code{archiveData} was \code{TRUE}, the result also
-#' has an attribute, named \code{data}, that determines \code{md5hash} of the data needed
+#' As a result of calling this function a character string is returned, which determines
+#' the \code{md5hash} of the artifact. If  
+#' \code{archiveData} is \code{TRUE}, the result will also
+#' have an attribute, named \code{data}, which determines \code{md5hash} of the data needed
 #' to compute the artifact.
 #' 
 #' @seealso
@@ -75,22 +80,26 @@
 #' 
 #' 
 #' @note 
-#' One can specify his own \code{Tags} for artifacts by setting artifact's attribute 
-#' before call of the \code{saveToRepo} function like this: 
-#' \code{attr(x, "tags" ) = c( "name1", "name2" )}, where \code{x} is artifact 
-#' and \code{name1, name2} are \code{Tags} specified by an user.
+#' In the following way one can specify his own \code{Tags} for artifacts by setting artifact's attribute 
+#' before call of the \code{saveToRepo} function: 
+#' \code{attr(x, "tags" ) = c( "name1", "name2" )}, where \code{x} is an artifact 
+#' and \code{name1, name2} are \code{Tags} specified by a user.
+#' It can be also done in a new, simpler way by using \code{userTags} parameter like this: 
+#'  \itemize{
+#'    \item \code{saveToRepo(model, repoDir, userTags = c("my_model", "do not delete"))}.
+#'  }
 #' 
-#' Important: if one want to archive data from arftifacts that class is one of: 
-#' \code{survfit, glmnet, qda, lda, trellis, htest}, and this dataset set is transformed only in
-#' the artifact's formula the \code{saveToRepo} will not archive this dataset. \code{saveToRepo}
-#' only archives datasets that already exists in any of R environments. 
+#' Important: if one wants to archive data from artifacts which is one of: 
+#' \code{survfit, glmnet, qda, lda, trellis, htest} class, and this dataset is transformed within
+#' the artifact's formula then \code{saveToRepo} will not archive this dataset. \code{saveToRepo}
+#' only archives datasets that already exist in any of R environments. 
 #' 
-#' Example: here data set will not be archived.
+#' Example: The data set will not be archived here.
 #' \itemize{
 #'    \item \code{z <- lda(Sp ~ ., Iris, prior = c(1,1,1)/3, subset = train[,-8])}
 #'    \item \code{saveToRepo( z, repoDir )}
 #' }
-#' Example: here data set will be archived.
+#' Example: The data set will be archived here.
 #' \itemize{
 #'    \item \code{train2 <- train[,-8]}
 #'    \item \code{z <- lda(Sp ~ ., Iris, prior = c(1,1,1)/3, subset = train2)}
@@ -99,38 +108,41 @@
 #' 
 #' @param artifact An arbitrary R artifact to be saved. For supported artifacts see details.
 #' 
-#' @param ... Graphical parameters denoting width and height of a miniature. See details.
+#' @param ... Graphical parameters denoting width and height of a miniature. See details. 
+#' Further arguments passed to \link{head}. See Details section about \code{firtsRows} parameter
 #' 
 #' @param archiveData A logical value denoting whether to archive the data from the \code{artifact}.
 #' 
-#' @param archiveTags A logical value denoting whether to archive tags from the \code{artifact}.
+#' @param archiveTags A logical value denoting whether to archive Tags from the \code{artifact}.
 #' 
 #' @param archiveMiniature A logical value denoting whether to archive a miniature of the \code{artifact}.
 #' 
-#' @param userTags A character vector with tags. These tags will be added to the repository along the artifact.
+#' @param userTags A character vector with Tags. These Tags will be added to the repository along with the artifact.
 #' 
 #' @param repoDir A character denoting an existing directory in which an artifact will be saved.
-#' If set to \code{NULL} (by default), uses the \code{repoDir} specified in \link{setLocalRepo}.
+#' If it is set to \code{NULL} (by default), it will use the \code{repoDir} specified in \link{setLocalRepo}.
 #' 
 #' @param force A logical value denoting whether to archive \code{artifact} if it was already archived in
 #' a Repository.
 #' 
-#' @param rememberName A logical value. Should not be changed by an user. It is a technical parameter.
+#' @param rememberName A logical value. Should not be changed by a user. It is a technical parameter.
 #' 
 #' @param chain A logical value. Should the result be (default \code{chain = FALSE}) the \code{md5hash} 
-#' of an stored artifact or should the result be the input artifact (\code{chain = TRUE}), so that chaining code 
+#' of a stored artifact or should the result be an input artifact (\code{chain = TRUE}), so that chaining code 
 #' can be used. See examples.
 #'
 #' @param silent If TRUE produces no warnings.
 #' 
 #' @param ascii A logical value. An \code{ascii} argument is passed to \link{save} function.
 #' 
+#' 
 #' @author 
 #' Marcin Kosinski , \email{m.p.kosinski@@gmail.com}
 #'
 #' @examples
-#' # objects preparation
 #' \dontrun{
+#' # objects preparation
+#'
 #' # data.frame object
 #' data(iris)
 #' 
@@ -183,11 +195,11 @@
 #' glmnet1=glmnet(zk,bk)
 #'
 #' 
-#' # creating example Repository - that examples will work
+#' # creating example Repository - on which examples will work
 #' 
 #' # save examples
 #' 
-#' exampleRepoDir <- tempdir()
+#' exampleRepoDir <- tempfile()
 #' createEmptyRepo( repoDir = exampleRepoDir )
 #' saveToRepo( myplot123, repoDir=exampleRepoDir )
 #' saveToRepo( iris, repoDir=exampleRepoDir )
@@ -197,56 +209,66 @@
 #' saveToRepo( lda1, repoDir=exampleRepoDir )
 #' saveToRepo( glmnet1, repoDir=exampleRepoDir )
 #' 
-#' # let's see how the Repository look like: show
+#' # let's see how the Repository looks like: show
 #' 
 #' showLocalRepo( method = "md5hashes", repoDir = exampleRepoDir )
 #' showLocalRepo( method = "tags", repoDir = exampleRepoDir )
 #' 
-#' # let's see how the Repository look like: summary
+#' # let's see how the Repository looks like: summary
 #' 
 #' summaryLocalRepo( exampleRepoDir )
 #' 
-#' # one can archived the same artifact twice, but there is a message
+#' # one can archive the same artifact twice, but there is a message
 #' 
 #' saveToRepo( model, repoDir=exampleRepoDir )
 #' 
-#' # in case not to archive the same artifact twice, use
+#' # in order not to archive the same artifact twice, use
 #' 
 #' saveToRepo( lda1, repoDir=exampleRepoDir, force = FALSE )
 #' 
-#' # one can archive artifact withouth it's database and miniature
+#' # one can archive artifact without it's database and miniature
 #' 
 #' saveToRepo( qda1, repoDir=exampleRepoDir, archiveData = FALSE,
 #'             archiveMiniature = FALSE)
 #' 
-#' # one can specify his own additional tags to be archived with artifact
+#' # one can specify his own additional Tags which are to be archived with artifact
 #' 
 #' attr( model, "tags" ) = c( "do not delete", "my favourite model" )
 #' saveToRepo( model, repoDir=exampleRepoDir )
-#' showLocalRepo( "tags", exampleRepoDir )
+#' showLocalRepo( method = "tags", repoDir = exampleRepoDir )
+#' 
+#' # or one can do it even easier
+#' saveToRepo( model, repoDir = exampleRepoDir, 
+#'             userTags = c( "do not delete", "my favourite model" ) )
 #' 
 #' # removing an example Repository
+#' deleteRepo( exampleRepoDir, TRUE)
+#' 
+#' rm( exampleRepoDir )
 #' 
 #' # saveToRepo in chaining code
 #' library(dplyr)
 #' 
+#' # chaining code
+#' exampleRepoDir <- tempdir()
+#' createEmptyRepo(exampleRepoDir, default = TRUE)
+#' library(dplyr)
+#' invisible(aoptions("silent", TRUE))
 #' data("hflights", package = "hflights")
 #' hflights %a%
 #'   group_by(Year, Month, DayofMonth) %a%
 #'   select(Year:DayofMonth, ArrDelay, DepDelay) %a%
-#'   saveToRepo( exampleRepoDir, chain = TRUE ) %a%
-#'   # here the artifact is stored but chaining is not finished
 #'   summarise(
 #'     arr = mean(ArrDelay, na.rm = TRUE),
 #'     dep = mean(DepDelay, na.rm = TRUE)
 #'   ) %a%
-#'   filter(arr > 30 | dep > 30) %a%
-#'   saveToRepo( exampleRepoDir )
-#'   # chaining code is finished and after last operation the 
-#'   # artifact is stored
+#'   filter(arr > 30 | dep > 30) -> x
+#' showLocalRepo() # Repository was globally set in aoptions
 #' 
 #' 
 #' 
+#' 
+#' # removing an example Repository
 #' deleteRepo( exampleRepoDir, TRUE)
 #' 
 #' rm( exampleRepoDir )
@@ -258,10 +280,11 @@ saveToRepo <- function( artifact, repoDir = NULL, archiveData = TRUE,
                         archiveTags = TRUE, 
                         archiveMiniature = TRUE, force = TRUE, rememberName = TRUE, 
                         chain = FALSE, ... , userTags = c(), 
-                        silent=aoptions("silent"), ascii = FALSE) {
+                        silent=aoptions("silent"), ascii = FALSE) { 
   stopifnot( is.logical( c( archiveData, archiveTags, archiveMiniature, 
-                                                     chain, rememberName ) ) )
-  stopifnot( is.character( repoDir ) | is.null( repoDir ) )
+                                                     chain, rememberName, ascii ) ) )
+  stopifnot( ( is.character( repoDir ) & length( repoDir ) == 1 ) | is.null( repoDir ) )
+#   stopifnot( is.character( format ) & length( format ) == 1 & any(format %in% c("rda", "rdx")) )
   
   md5hash <- digest( artifact )
   objectName <- deparse( substitute( artifact ) )
@@ -289,33 +312,41 @@ saveToRepo <- function( artifact, repoDir = NULL, archiveData = TRUE,
     rememberName = FALSE
   }
   if ( rememberName ){
-    save( file = paste0(repoDir,"gallery/", md5hash, ".rda"), ascii = ascii, list = objectName,  envir = parent.frame(1))
+#     if( format == "rda"){
+      save( file = file.path(repoDir,"gallery", paste0(md5hash, ".rda")), ascii = ascii, list = objectName,  envir = parent.frame(1))
+#     }else{
+#       saveToRepo2(artifact, filebase = paste0(repoDir,"gallery/", md5hash), ascii = ascii, ...)
+#     }
   }else{ 
 #    assign( value = artifact, x = md5hash, envir = .GlobalEnv )
 #    save( file = paste0(repoDir, "gallery/", md5hash, ".rda"),  ascii=TRUE, list = md5hash, envir = .GlobalEnv  )
     assign( value = artifact, x = md5hash, envir = .ArchivistEnv )
-    save( file = paste0(repoDir, "gallery/", md5hash, ".rda"),  ascii=ascii, list = md5hash, envir = .ArchivistEnv  )
+#     if( format == "rda" ){
+      save( file = file.path(repoDir, "gallery", paste0(md5hash, ".rda")),  ascii=ascii, list = md5hash, envir = .ArchivistEnv  )
+#     }else{
+#       saveToRepo2(artifact, filebase = paste0(repoDir,"gallery/", md5hash), ascii = ascii, ...)
+#     }
     rm(list = md5hash, envir = .ArchivistEnv)
   }
   
   # add entry to database 
    if ( rememberName ){
-  addArtifact( md5hash, name = objectName, dir = repoDir ) 
+     addArtifact( md5hash, name = objectName, dir = repoDir ) 
    }else{
-   addArtifact( md5hash, name = md5hash , dir = repoDir)
-#   # rm( list = md5hash, envir = .ArchivistEnv ) 
+     addArtifact( md5hash, name = md5hash , dir = repoDir)
+   # rm( list = md5hash, envir = .ArchivistEnv ) 
    }
   
-  # whether to add tags
+  # whether to add Tags
   if ( archiveTags ) {
     extractedTags <- extractTags( artifact, objectNameX = objectName )
-    # remove name from tags
+    # remove name from Tags
     if (!rememberName) {
       extractedTags <- extractedTags[!grepl(extractedTags, pattern="^name:")]
     }
     derivedTags <- attr( artifact, "tags" ) 
     sapply( c( extractedTags, userTags, derivedTags), addTag, md5hash = md5hash, dir = repoDir )
-    # attr( artifact, "tags" ) are tags specified by an user
+    # attr( artifact, "tags" ) are Tags specified by a user
   }
   
   # whether to archive data 
@@ -339,3 +370,95 @@ saveToRepo <- function( artifact, repoDir = NULL, archiveData = TRUE,
     return( artifact )
   }
 }
+
+
+# # getFromNamespace(x = "makeLazyLoadDB", "tools")
+# saveToRepo2 <- function (from, filebase, compress = TRUE, ascii = FALSE, variables) 
+# {
+#   ascii <- as.logical(ascii)
+#   if (is.na(ascii)) 
+#     stop("'ascii' must be TRUE or FALSE", domain = NA)
+#   ascii <- as.integer(ascii)
+#   envlist <- function(e) .Internal(getVarsFromFrame(ls(e, all.names = TRUE), 
+#                                                     e, FALSE))
+#   envtable <- function() {
+#     idx <- 0
+#     envs <- NULL
+#     enames <- character(0L)
+#     find <- function(v, keys, vals) {
+#       for (i in seq_along(keys)) if (identical(v, keys[[i]])) 
+#         return(vals[i])
+#       NULL
+#     }
+#     getname <- function(e) find(e, envs, enames)
+#     getenv <- function(n) find(n, enames, envs)
+#     insert <- function(e) {
+#       idx <<- idx + 1
+#       name <- paste("env", idx, sep = "::")
+#       envs <<- c(e, envs)
+#       enames <<- c(name, enames)
+#       name
+#     }
+#     list(insert = insert, getenv = getenv, getname = getname)
+#   }
+#   lazyLoadDBinsertValue <- function(value, file, ascii, compress, 
+#                                     hook) .Internal(lazyLoadDBinsertValue(value, file, ascii, 
+#                                                                           compress, hook))
+#   lazyLoadDBinsertListElement <- function(x, i, file, ascii, 
+#                                           compress, hook) .Internal(lazyLoadDBinsertValue(x[[i]], 
+#                                                                                           file, ascii, compress, hook))
+#   lazyLoadDBinsertVariable <- function(n, e, file, ascii, compress, 
+#                                        hook) {
+#     x <- .Internal(getVarsFromFrame(n, e, FALSE))
+#     .Internal(lazyLoadDBinsertValue(x[[1L]], file, ascii, 
+#                                     compress, hook))
+#   }
+#   mapfile <- paste(filebase, "rdx", sep = ".")
+#   datafile <- paste(filebase, "rdb", sep = ".")
+#   close(file(datafile, "wb"))
+#   table <- envtable()
+#   varenv <- new.env(hash = TRUE)
+#   envenv <- new.env(hash = TRUE)
+#   envhook <- function(e) {
+#     if (is.environment(e)) {
+#       name <- table$getname(e)
+#       if (is.null(name)) {
+#         name <- table$insert(e)
+#         data <- list(bindings = envlist(e), enclos = parent.env(e), 
+#                      attributes = attributes(e), isS4 = isS4(e), 
+#                      locked = environmentIsLocked(e))
+#         key <- lazyLoadDBinsertValue(data, datafile, 
+#                                      ascii, compress, envhook)
+#         assign(name, key, envir = envenv)
+#       }
+#       name
+#     }
+#   }
+#   if (is.null(from) || is.environment(from)) {
+#     if (!missing(variables)) 
+#       vars <- variables
+#     else vars <- ls(from, all.names = TRUE)
+#   }
+#   else if (is.list(from)) {
+#     vars <- names(from)
+#     if (length(vars) != length(from) || any(!nzchar(vars))) 
+#       stop("source list must have names for all elements")
+#   }
+#   else stop("source must be an environment or a list")
+#   for (i in seq_along(vars)) {
+#     key <- if (is.null(from) || is.environment(from)) 
+#       lazyLoadDBinsertVariable(vars[i], from, datafile, 
+#                                ascii, compress, envhook)
+#     else lazyLoadDBinsertListElement(from, i, datafile, ascii, 
+#                                      compress, envhook)
+#     assign(vars[i], key, envir = varenv)
+#   }
+#   vals <- lapply(vars, get, envir = varenv, inherits = FALSE)
+#   names(vals) <- vars
+#   rvars <- ls(envenv, all.names = TRUE)
+#   rvals <- lapply(rvars, get, envir = envenv, inherits = FALSE)
+#   names(rvals) <- rvars
+#   val <- list(variables = vals, references = rvals, compressed = compress)
+#   saveRDS(val, mapfile)
+# }
+
