@@ -1,71 +1,77 @@
 ##    archivist package for R
 ##
-#' @title Search for an Artifact in a Repository Using Tags
+#' @title Search for an Artifact in the Repository Using Tags
 #'
 #' @description
-#' \code{searchInRepo} searches for an artifact in a \link{Repository} using it's \link{Tags}.
+#' \code{searchInRepo} searches for an artifact in the \link{Repository} using it's \link{Tags}.
 #' To learn more about artifacts visit \link[archivist]{archivist-package}.
 #' 
 #' 
 #' @details
-#' \code{searchInRepo} searches for an artifact in a Repository using it's \code{Tag} 
-#' (e.g., \code{name}, \code{class} or \code{archiving date}). \code{Tags} are submitted in a \code{pattern}
-#' argument. For various artifact classes different \code{Tags} can be searched for. 
-#' See \link{Tags}. If a \code{pattern} is a list of length 2, \code{md5hashes} of all 
-#' artifacts created from date \code{dateFrom} to data \code{dateTo} are returned. The date 
+#' \code{searchInRepo} searches for an artifact in the Repository using it's \code{Tag} 
+#' (e.g., \code{name}, \code{class} or \code{archiving date}). \code{Tags} are used in a \code{pattern}
+#' parameter. For various artifact classes different \code{Tags} can be searched for. 
+#' See \link{Tags}. If a \code{pattern} is a list of length 2 then \code{md5hashes} of all 
+#' artifacts created from date \code{dateFrom} to date \code{dateTo} are returned. The date 
 #' should be formatted according to the YYYY-MM-DD format, e.g., \code{"2014-07-31"}.
 #' 
-#' \code{Tags}, submitted in a \code{pattern} argument, should be given according to the 
-#' format: \code{"TagType:TagTypeValue"} - see examples.
+#' \code{Tags}, used in a \code{pattern} parameter, should be determined according to the 
+#' format: \code{"TagKey:TagValue"} - see examples.
 #'   
 #' @return
-#' \code{searchInRepo} returns a \code{md5hash} character, which is a hash assigned to the artifact when
-#' saving it to the Repository by using the \link{saveToRepo} function. If the artifact
-#' is not in the Repository a logical value \code{FALSE} is returned.
+#' \code{searchInRepo} returns character vector of \code{md5hashes} of artifacts that were searched for.
+#' Those are hashes assigned to artifacts while they were saved in the Repository
+#' by the \link{saveToRepo} function. If the artifact
+#' is not in the Repository then a logical value \code{FALSE} is returned.
 #' 
-#' @param pattern If \code{fixed = TRUE}: a character denoting a \link{Tags} to be searched for in the Repository. 
+#' @param pattern If \code{fixed = TRUE}: a character denoting a \code{Tag} which is to be searched for in the Repository.
 #' It is also possible to specify \code{pattern} as a list of 
-#' length 2 with \code{dataFrom} and \code{dataTo}; see details. If \code{fixed = FALSE}: A regular expression 
-#' specifying the beginning of a \link{Tags}, which will be used to search artifacts for.
+#' length 2 with \code{dateFrom} and \code{dateTo}; see details. If \code{fixed = FALSE}: a regular expression 
+#' specifying the beginning of a \code{Tag}, which will be used to search for artifacts.
 #' 
-#' @param patterns A vector of queries to repository. If \code{intersect = TRUE} only artifacts that 
-#' match all conditions are returned. If \code{intersect = FALSE} then artifacts that match any contition
+#' @param patterns A character vector of \code{patterns}(see \code{pattern}) to find artifacts in the Repository.
+#' If \code{intersect = TRUE} then artifacts that 
+#' match all conditions are returned. If \code{intersect = FALSE} then artifacts that match any condition
 #' are returned.
 #' 
 #' @param intersect A logical value. See \code{patterns} for more details.
 #' 
-#' @param repoDir A character denoting an existing directory in which artifacts will be searched.
-#' If set to \code{NULL} (by default), uses the \code{repoDir} specified in \link{setLocalRepo}.
+#' @param repoDir A character denoting an existing directory in which artifacts will be searched for.
+#' If it is set to \code{NULL} (by default), it will use the \code{repoDir} specified in \link{setLocalRepo}.
 #' 
-#' @param repo Only if working with a Github repository. A character containing a name of a Github repository on which the Repository is archived.
+#' @param repo While working with the Github repository. A character containing a name of the Github repository on which the Repository is stored.
 #' By default set to \code{NULL} - see \code{Note}.
-#' @param user Only if working with a Github repository. A character containing a name of a Github user on whose account the \code{repo} is created.
+#' 
+#' @param user While working with the Github repository. A character containing a name of the Github user on whose account the \code{repo} is created.
 #' By default set to \code{NULL} - see \code{Note}.
-#' @param branch Only if working with a Github repository. A character containing a name of 
-#' Github repository's branch in which Repository is archived. Default \code{branch} is \code{master}.
+#'
+#' @param branch While working with the Github repository. A character containing a name of 
+#' the Github Repository's branch on which the Repository is stored. Default \code{branch} is \code{master}.
 #' 
 #' @param fixed A logical value specifying how \code{artifacts} should be searched for.
-#' If \code{fixed = TRUE} (default) then artifacts are searched exactly to the corresponding \code{pattern} parameter. If
-#' \code{fixed = FALSE} then artifacts are searched using \code{pattern} paremeter as a regular expression - that method is wider and more flexible 
-#' and, i.e., enables to search for all artifacts in the \code{Repository}, using \code{pattern = "name", fixed = FALSE}.
+#' If \code{fixed = TRUE} (default) then artifacts are searched for by using \code{pattern = "Tag"} argument.
+#' If \code{fixed = FALSE} then artifacts are searched for by using \code{pattern = "regular expression"} argument.
+#' The latter is wider and more flexible method, e.g.,
+#' using \code{pattern = "name", fixed = FALSE} arguments enables to search for all artifacts in the \code{Repository}.
 #' 
-#' @param repoDirGit Only if working with a Github repository. A character containing a name of a directory on Github repository 
-#' on which the Repository is stored. If the Repository is stored in main folder on Github repository, this should be set 
+#' @param repoDirGit While working with the Github repository. A character containing a name of a directory on the Github repository 
+#' on which the Repository is stored. If the Repository is stored in the main folder of the Github repository, this should be set 
 #' to \code{repoDirGit = FALSE} as default.
 #' 
 #' @param realDBname A logical value. Should not be changed by user. It is a technical parameter.
 #'
 #' @note
-#' If \code{repo} and \code{user} are set to \code{NULL} (as default) in Github mode then global parameters
+#' If \code{repo} and \code{user} are set to \code{NULL} (as default) in the Github mode then global parameters
 #' set in \link{setGithubRepo} function are used.
 #' 
 #' @author
 #' Marcin Kosinski, \email{m.p.kosinski@@gmail.com}
 #'
 #' @examples
-#' # objects preparation
 #' \dontrun{
-#'   # data.frame object
+#' # objects preparation
+#' 
+#'  # data.frame object
 #'   data(iris)
 #'   
 #'  # ggplot/gg object
@@ -91,9 +97,9 @@
 #'              cbind(rnorm( 3,3.2,0.5), rnorm( 3,3.2,0.5)))
 #'   fannyx <- fanny(x, 2)
 #'   
-#'   # creating example Repository - that examples will work
+#'   # creating example Repository - on which examples will work
 #'   
-#'   exampleRepoDir <- tempdir()
+#'   exampleRepoDir <- tempfile()
 #'   createEmptyRepo(repoDir = exampleRepoDir)
 #'   saveToRepo(myplot123, repoDir=exampleRepoDir)
 #'   saveToRepo(iris, repoDir=exampleRepoDir)
@@ -101,19 +107,19 @@
 #'   saveToRepo(agn1, repoDir=exampleRepoDir)
 #'   saveToRepo(fannyx, repoDir=exampleRepoDir)
 #'   
-#'   # let's see how the Repository look like: show
+#'   # let's see how the Repository looks like: show
 #'   
 #'   showLocalRepo(method = "md5hashes", repoDir = exampleRepoDir)
 #'   showLocalRepo(method = "tags", repoDir = exampleRepoDir)
 #'   
-#'   # let's see how the Repository look like: summary
+#'   # let's see how the Repository looks like: summary
 #'   
 #'   summaryLocalRepo( exampleRepoDir )
 #'   
 #'   
 #'   # search examples
 #'   
-#'   # tag search, fixed version
+#'   # Tag search, fixed version
 #'   searchInLocalRepo( "class:ggplot", repoDir = exampleRepoDir )
 #'   searchInLocalRepo( "name:myplot123", repoDir = exampleRepoDir )
 #'   searchInLocalRepo( "varname:Sepal.Width", repoDir = exampleRepoDir )
@@ -121,7 +127,7 @@
 #'   searchInLocalRepo( "coefname:Petal.Length", repoDir = exampleRepoDir )
 #'   searchInLocalRepo( "ac:0.797755535467609", repoDir = exampleRepoDir )
 #'   
-#'   # tag search, regex version
+#'   # Tag search, regex version
 #'   
 #'   searchInLocalRepo( "class", repoDir = exampleRepoDir, fixed = FALSE )
 #'   searchInLocalRepo( "name", repoDir = exampleRepoDir, fixed = FALSE )
@@ -132,12 +138,12 @@
 #'   showGithubRepo( user="pbiecek", repo="archivist" )
 #'   showGithubRepo( user="pbiecek", repo="archivist", method = "tags" )
 #'   
-#'   # tag search, fixed version
+#'   # Tag search, fixed version
 #'   searchInGithubRepo( "varname:Sepal.Width", user="pbiecek", repo="archivist" )
 #'   searchInGithubRepo( "class:lm", user="pbiecek", repo="archivist", branch="master" )
 #'   searchInGithubRepo( "name:myplot123", user="pbiecek", repo="archivist" )
 #'   
-#'   # tag search, regex version
+#'   # Tag search, regex version
 #'   searchInGithubRepo( "class", user="pbiecek", repo="archivist",  fixed = FALSE )
 #'   searchInGithubRepo( "name", user="pbiecek", repo="archivist", fixed = FALSE )
 #'   
@@ -150,12 +156,13 @@
 #'   
 #'   # also on Github
 #'   
-#'   searchInGithubRepo( pattern = list( dateFrom = "2014-09-01", dateTo = "2014-09-30" ), 
+#'   # Remeber to set dateTo parameter to actual date because sometimes we update datasets.
+#'   searchInGithubRepo( pattern = list( dateFrom = "2015-10-01", dateTo = "2015-11-30" ), 
 #'                       user="pbiecek", repo="archivist", branch="master" )
 #'   
 #'   
 #'   # objects from Today
-#'   searchInLocalRepo( pattern = list( dateFrom=Sys.Date(), dateTo=Sys.Date() ), 
+#'   searchInLocalRepo( pattern = list( dateFrom = Sys.Date(), dateTo = Sys.Date() ), 
 #'                      repoDir = exampleRepoDir )
 #'   
 #'   # removing an example Repository
@@ -181,7 +188,7 @@
 #' @rdname searchInRepo
 #' @export
 searchInLocalRepo <- function( pattern, repoDir = NULL, fixed = TRUE, realDBname = TRUE ){
-  stopifnot( is.character( repoDir ) | is.null( repoDir ) )
+  stopifnot( ( is.character( repoDir ) & length( repoDir ) == 1 ) | is.null( repoDir ) )
   stopifnot( is.logical( fixed ) )
   stopifnot( is.character( pattern ) | is.list( pattern ) ) 
   stopifnot( length( pattern ) == 1 | length( pattern ) == 2 )
@@ -218,7 +225,7 @@ searchInLocalRepo <- function( pattern, repoDir = NULL, fixed = TRUE, realDBname
 searchInGithubRepo <- function( pattern, repo = NULL, user = NULL, branch = "master", repoDirGit = FALSE,
                                 fixed = TRUE ){
 
-  stopifnot( is.character( branch ), is.logical( fixed ) )
+  stopifnot( is.character( branch ), is.logical( fixed ), length( branch ) == 1 )
   stopifnot( is.character( pattern ) | is.list( pattern ) )
   stopifnot( length( pattern ) == 1 | length( pattern ) == 2 )
 
@@ -274,9 +281,9 @@ multiSearchInGithubRepo <- function( patterns, repo = NULL, user = NULL,
   GithubCheck( repo, user, repoDirGit ) # implemented in setRepo.R
   
   Temp <- downloadDB( repo, user, branch, repoDirGit )
+  on.exit(file.remove( Temp ))
   m <- multiSearchInLocalRepo( patterns, repoDir = Temp, fixed=fixed,
                                intersect=intersect, realDBname = FALSE)
-  file.remove( Temp )
   return( m )
 }
 
